pub struct KeyPair {
    pub public_key: PublicKeyInfo,
    /* private fields */
}
Serializable struct to hold pair of public and private keys. Universal for any key types as keys stored as bytes.

Fields

public_key: PublicKeyInfo

Public key is instance of PublicKeyInfo struct.

Implementations

Constructs set of keys from private key. Public key generated in the method from private key provided.

Arguments

*key_type - variont of KeyType enum. Currently supportet key types are: Ed25519VerificationKey2018 W3C
EcdsaSecp256k1VerificationKey2019 W3C
EcdsaSecp256k1RecoveryMethod2020 W3C
X25519KeyAgreementKey2019 W3C

Generates random KeyPair of specified KeyType type.

*key_type - variont of KeyType enum.

Examples
    let key_pair = KeyPair::random_pair(KeyType::EcdsaSecp256k1VerificationKey2019)?;

Updates .controller property to provided value.

*controller - collection of controller Strings.

Signst provided message with the key from KeyType set during KeyPair creation.

*data - message slice to be signed

Returns Result of generated signature in form of Vec<u8> or Error.

Decrypts cipher data using current private key.

*data - cipher to be derypted.

Returns Result of raw representation of the data in form of Vec<u8> or Error indication failure.

Performs ECDH key agreement

*pk - public key to perform agreement with

Returns Result of shared secret in Vec<u8> form`

Returns Cloned instance of PublicKeyInfo from own public_key property.

Returns Cloned instance of Vec<u8> from own private key.