pub struct KeyPair {
pub public_key: PublicKeyInfo,
/* private fields */
}Expand description
Serializable struct to hold pair of public and private keys. Universal for any key types as keys stored as bytes.
Fields
public_key: PublicKeyInfoPublic key is instance of PublicKeyInfo struct.
Implementations
sourceimpl KeyPair
impl KeyPair
sourcepub fn new(key_type: KeyType, priv_key: &[u8]) -> Result<Self, Error>
pub fn new(key_type: KeyType, priv_key: &[u8]) -> Result<Self, Error>
Constructs set of keys from private key. Public key generated in the method from private key provided.
Arguments
*key_type - variont of KeyType enum.
Currently supportet key types are:
Ed25519VerificationKey2018 W3C
EcdsaSecp256k1VerificationKey2019 W3C
EcdsaSecp256k1RecoveryMethod2020 W3C
X25519KeyAgreementKey2019 W3C
sourcepub fn random_pair(key_type: KeyType) -> Result<KeyPair, Error>
pub fn random_pair(key_type: KeyType) -> Result<KeyPair, Error>
Generates random KeyPair of specified KeyType type.
*key_type - variont of KeyType enum.
Examples
let key_pair = KeyPair::random_pair(KeyType::EcdsaSecp256k1VerificationKey2019)?;sourcepub fn set_controller(self, controller: Vec<String>) -> Self
pub fn set_controller(self, controller: Vec<String>) -> Self
Updates .controller property to provided value.
*controller - collection of controller Strings.
sourcepub fn sign(&self, data: &[u8]) -> Result<Vec<u8>, Error>
pub fn sign(&self, data: &[u8]) -> Result<Vec<u8>, Error>
Signst provided message with the key from KeyType set during KeyPair creation.
*data - message slice to be signed
Returns Result of generated signature in form of Vec<u8> or Error.
sourcepub fn decrypt(
&self,
data: &[u8],
_aad: Option<&[u8]>
) -> Result<Vec<u8>, Error>
pub fn decrypt(
&self,
data: &[u8],
_aad: Option<&[u8]>
) -> Result<Vec<u8>, Error>
Decrypts cipher data using current private key.
*data - cipher to be derypted.
Returns Result of raw representation of the data in form of Vec<u8> or
Error indication failure.
sourcepub fn ecdh_key_agreement(&self, pk: &[u8]) -> Result<Vec<u8>, Error>
pub fn ecdh_key_agreement(&self, pk: &[u8]) -> Result<Vec<u8>, Error>
Performs ECDH key agreement
*pk - public key to perform agreement with
Returns Result of shared secret in Vec<u8> form`
sourcepub fn get_public_key(&self) -> PublicKeyInfo
pub fn get_public_key(&self) -> PublicKeyInfo
Returns Cloned instance of PublicKeyInfo from own public_key property.
sourcepub fn private_key(&self) -> Vec<u8>
pub fn private_key(&self) -> Vec<u8>
Returns Cloned instance of Vec<u8> from own private key.